==> sqliterally-0.0.1-1.tgz: package/index.js <==
class SQLiterally {
  constructor(strings, values, dubplicates = true) {
    this._strings = Array.from(strings);
    this._values = Array.from(values);
    // TODO:
    // find index in array for string, if value already in values use that index
    // skip duplicates in values (use set instead od array?)
    // replace duplicates with special symbols, and pop them when building the string?
    // create a map before building the string?
  }

  get() {
    return { text: this.text, values: this.values };
  }

  get text() {
    return this.strings.reduce((prev, curr, i) => {
      let value = this.values[i-1];
      return `${prev}$${i}${curr}`; 
    });
  }

  get strings() {
    if (this._stringsCache) return this._stringsCache; 
    let result = [], arr, str, val;
    for (let i = 0; i < this._strings.length; i++) {
      str = this._strings[i];
      val = this._values[i-1];
      if (val instanceof SQLiterally) {
        arr = val.strings;
        result[result.length-1] += arr.shift();
        result.push(...arr);
        result[result.length-1] += str;
      } else {
        result.push(str);
      }
    }
    return this._stringsCache = result;
  }

  get values() {
    if (this._valuesCache) return this._valuesCache;
    return this._valuesCache = this._values.reduce((prev, curr, i) => {
      return curr instanceof SQLiterally ? prev.concat(...curr.values) : prev.concat(curr);
    }, []);
  }

  append(statement) {
    this._stringsCache = this._valuesCache = null;
    if (statement instanceof SQLiterally) {
      this._strings[this._strings.length - 1] += statement._strings[0];
      this._strings.push(...statement._strings.slice(1));
      this._values.push(...statement._values);
    } else {
      this._strings[this._strings.length - 1] += statement;
    }
    return this;
  }
}

function SQL(strings, ...values) {
  return new SQLiterally(strings, values);
}

SQL.join = function(arr) {
  return arr.reduce((acc, curr, i) => {
    return acc.append(curr);
  });
}

module.exports = SQL;

==> sqliterally-0.0.1-2.tgz: package/index.js <==
class SQLiterally {
  constructor(strings, values, dubplicates = true) {
    this._strings = Array.from(strings);
    this._values = Array.from(values);
    // TODO:
    // find index in array for string, if value already in values use that index
    // skip duplicates in values (use set instead od array?)
    // replace duplicates with special symbols, and pop them when building the string?
    // create a map before building the string?
  }

  get() {
    return { text: this.text, values: this.values };
  }

  get text() {
    return this.strings.reduce((prev, curr, i) => {
      let value = this.values[i-1];
      return `${prev}$${i}${curr}`; 
    });
  }

  get strings() {
    if (this._stringsCache) return this._stringsCache; 
    let result = [], arr, str, val;
    for (let i = 0; i < this._strings.length; i++) {
      str = this._strings[i];
      val = this._values[i-1];
      if (val instanceof SQLiterally) {
        arr = val.strings;
        result[result.length-1] += arr.shift();
        result.push(...arr);
        result[result.length-1] += str;
      } else {
        result.push(str);
      }
    }
    return this._stringsCache = result;
  }

  get values() {
    if (this._valuesCache) return this._valuesCache;
    return this._valuesCache = this._values.reduce((prev, curr, i) => {
      return curr instanceof SQLiterally ? prev.concat(...curr.values) : prev.concat(curr);
    }, []);
  }

  append(statement) {
    this._stringsCache = this._valuesCache = null;
    if (statement instanceof SQLiterally) {
      this._strings[this._strings.length - 1] += statement._strings[0];
      this._strings.push(...statement._strings.slice(1));
      this._values.push(...statement._values);
    } else {
      this._strings[this._strings.length - 1] += statement;
    }
    return this;
  }
}

function SQL(strings, ...values) {
  return new SQLiterally(strings, values);
}

SQL.join = function(arr, delimiter = ' ') {
  return arr.reduce((acc, curr, i) => {
    return acc.append(delimiter).append(curr);
  });
}

module.exports = SQL;
